import { COMPRESS_TYPE } from './types/all.js';
import { promises } from 'fs';
import { glob } from 'glob';
import chalk from 'chalk';
import { endings } from './core/constants.js';
import ValidationService from './core/services/ValidationService.js';
import CompressorsContainer from './core/CompressorsContainer.js';
import SizeCounter from './utils/SizeCounter.js';
async function Compress(quality, directory, type = COMPRESS_TYPE.WEBP) {
    const compressor = new CompressorsContainer[type](quality);
    const files = await glob(`${directory}/**/*${endings}`);
    for (const file of files) {
        try {
            const originalStats = await promises.stat(file);
            if (ValidationService.isFileValid(originalStats, file)) {
                const compressedDTOs = await compressor.compress(file);
                for (const compressedDTO of compressedDTOs) {
                    const outputSize = Buffer.byteLength(compressedDTO.buffer);
                    if (originalStats.size - outputSize > 0) {
                        await compressor.writingCompressedFile(compressedDTO);
                    }
                    SizeCounter.count(originalStats.size, outputSize, file);
                }
            }
        }
        catch (e) {
            console.error(chalk.yellow(e));
        }
    }
    console.log(chalk.magenta(`[Total compressed]: ${SizeCounter.getSize()}`));
}
export { Compress, COMPRESS_TYPE };
